==> cli_jobalert_app-0.1.tar.gz: cli_jobalert_app-0.1/setup.py <==
from distutils.core import setup
setup(
    name = 'cli_jobalert_app',         # How you named your package folder (MyLib)
    packages = ['cli_jobalert_app'],   # Chose the same as "name"
    version = '0.1',      # Start with a small number and increase it with every change you make
    license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    description = 'This is a cli_application that stores job postings and help users locate jobs around them',   # Give a short description about your library
    author = 'Andrew Gabriel',                   # Type in your name
    author_email = 'buedgabby@gmail.com',      # Type in your E-Mail
    url = 'https://github.com/Gabriel01osabuede/',   # Provide either the link to your github or to your website
    download_url = 'https://github.com/Gabriel01osabuede/cli_app_jobalert/archive/0.1.tar.gz',    # I explain this later on
    keywords = ['users', 'posts', 'jobs'],   # Keywords that define your package best
    install_requires=[
        '' # I get to this in a second
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Intended Audience :: Developers',      # Define that your audience are developers
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',   # Again, pick a license
        'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
)

==> cli_jobalert_app-0.1.2.tar.gz: cli_jobalert_app-0.1.2/setup.py <==
from distutils.core import setup
setup(
    name = 'cli_jobalert_app',         # How you named your package folder (MyLib)
    packages = ['cli_jobalert_app'],   # Chose the same as "name"
    version = '0.1.2',      # Start with a small number and increase it with every change you make
    license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    description = 'This is a cli_application that stores job postings and help users locate jobs around them',   # Give a short description about your library
    author = 'Andrew Gabriel',                   # Type in your name
    author_email = 'buedgabby@gmail.com',      # Type in your E-Mail
    url = 'https://github.com/Gabriel01osabuede/',   # Provide either the link to your github or to your website
    download_url = 'https://github.com/Gabriel01osabuede/cli_app_jobalert/archive/0.1.2.tar.gz',    # I explain this later on
    keywords = ['users', 'posts', 'jobs'],   # Keywords that define your package best
    install_requires=[
        '' # I get to this in a second
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Intended Audience :: Developers',      # Define that your audience are developers
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',   # Again, pick a license
        'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
)
